@@ -96,6 +96,7 @@ char TForm1::CreateTextPane(SWModule *mod, char *font) {
 	
 	newtab->Caption = mod->Name();
 	newtab->Hint = mod->Description();
+	newtab->ParentShowHint = true;
 	newtab->PageControl = PageControl1;
 	newrtf->Parent = newtab;
 	newrtf->Align = alClient;
@@ -163,6 +164,7 @@ char TForm1::CreateCommentPane(SWModule *mod) {
 
 	newtab->Caption = mod->Name();
 	newtab->Hint = mod->Description();
+	newtab->ParentShowHint = true;
 	newtab->PageControl = PageControl2;
 	newrtf->Parent = newtab;
 	newrtf->Align = alClient;
@@ -178,6 +180,7 @@ char TForm1::CreateLDPane(SWModule *mod) {
 
 	newtab->Caption = mod->Name();
 	newtab->Hint = mod->Description();
+	newtab->ParentShowHint = true;
 	newtab->PageControl = PageControl3;
 	newrtf->Parent = newtab;
 	newrtf->Align = alClient;
@@ -384,6 +387,12 @@ void __fastcall TForm1::FormShow(TObject *Sender)
 		FileMgr::systemFileMgr.maxFiles = maxFiles;
 	}
 
+	tmpval = ((eit = optionsconf->Sections["Hints"].find("On")) != optionsconf->Sections["Hints"].end())? (*eit).second : (string)"1";
+
+	if (atoi(tmpval.c_str()))
+		Form1->ShowHint = true;
+	else Form1->ShowHint = false;
+	
 	DefaultVSKey = TOP;
 	cbBook->Clear();
 	while (!DefaultVSKey.Error()) {
@@ -720,8 +729,10 @@ void __fastcall TForm1::Options1Click(TObject *Sender)
 {
 	ModMap::iterator it;
 	SectionMap::iterator sit;
+	ConfigEntMap::iterator eit;
 	ConfigEntMap emap;
 	int color;
+	string tmpval;
 
 	if ((sit = optionsconf->Sections.find("Appearance")) != optionsconf->Sections.end()) {
 		Optionsfrm->CurrentVSColor->Brush->Color = 
@@ -737,7 +748,13 @@ void __fastcall TForm1::Options1Click(TObject *Sender)
 		Optionsfrm->AutoBMPersonal->Checked = ((atoi((*(*sit).second.find("AutoSavePersonal")).second.c_str()))?true:false);
 		Optionsfrm->AutoBMOther->Checked    = ((atoi((*(*sit).second.find("AutoSaveOther")).second.c_str()))?true:false);
 	}
-		
+
+	
+	Optionsfrm->HintPopups->Checked = true;
+	tmpval = ((eit = optionsconf->Sections["Hints"].find("On")) != optionsconf->Sections["Hints"].end())? (*eit).second : (string)"1";
+	if (!atoi(tmpval.c_str()))
+		Optionsfrm->HintPopups->Checked = false;
+
 	if (Optionsfrm->ShowModal() == mrOk) {
 		emap = optionsconf->Sections["Appearance"];
 		color = Optionsfrm->CurrentVSColor->Brush->Color;
@@ -753,8 +770,19 @@ void __fastcall TForm1::Options1Click(TObject *Sender)
 		emap.erase("AutoSaveOther"); emap.insert(ConfigEntMap::value_type("AutoSaveOther", IntToStr((Optionsfrm->AutoBMOther->Checked)?1:0).c_str()));
 		optionsconf->Sections["Bookmarks"] = emap;
 
+		emap = optionsconf->Sections["Hints"];
+		emap.erase("On"); emap.insert(ConfigEntMap::value_type("On", IntToStr((Optionsfrm->HintPopups->Checked)?1:0).c_str()));
+		optionsconf->Sections["Hints"] = emap;
+
 		optionsconf->Save();
 	}
+
+	tmpval = ((eit = optionsconf->Sections["Hints"].find("On")) != optionsconf->Sections["Hints"].end())? (*eit).second : (string)"1";
+
+	if (atoi(tmpval.c_str()))
+		Form1->ShowHint = true;
+	else Form1->ShowHint = false;
+
 }
 //---------------------------------------------------------------------------
 void __fastcall TForm1::cbBookChange(TObject *Sender)
